ntrfc.geometry package
======================

Submodules
----------

ntrfc.geometry.alphashape module
--------------------------------

.. automodule:: ntrfc.geometry.alphashape
   :members:
   :undoc-members:
   :show-inheritance:

ntrfc.geometry.line module
--------------------------

.. automodule:: ntrfc.geometry.line
   :members:
   :undoc-members:
   :show-inheritance:

ntrfc.geometry.plane module
---------------------------

.. automodule:: ntrfc.geometry.plane
   :members:
   :undoc-members:
   :show-inheritance:

ntrfc.geometry.surface module
-----------------------------

.. automodule:: ntrfc.geometry.surface
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ntrfc.geometry
   :members:
   :undoc-members:
   :show-inheritance:
